@@ -3,7 +3,6 @@
 #' Calculates all 23 colorimetric variables reviewed in 
 #' Montgomerie (2006).
 #'
-#' @export 
 #'
 #' @param object (required) a data frame, possibly an object of class \code{rspec},
 #' with a column with wavelength data, named 'wl', and the remaining column containing
@@ -14,7 +13,7 @@
 #' Andersson and Prager 2006) are returned. Finally, a user-specified string of variable 
 #' names can be used in order to filter and show only those variables.
 #' @param wlmin,wlmax minimum and maximum used to define the range of wavelengths used in
-#' calculations (default is to use entire range in the \code{rspec} object)
+#' calculations (default is to use entire range in the \code{rspec} object).
 #' @param ... class consistency (ignored)
 #' @return A data frame containing either 23 or 5 (\code{subset = TRUE}) variables described 
 #' in Montgomerie (2006) with spectra name as row names. 
@@ -26,21 +25,21 @@
 #'
 #' B1 (Total brightness): Sum of the relative reflectance over the entire spectral
 #' range (area under the curve). Frequently used but should be discouraged because
-#' values are difficult to compare across studies (B2 is preferred). REF 1-4, 6, 8,
-#' 10, 13
+#' values are difficult to compare across studies (B2 is preferred). REF 1-3, 7, 9-11,
+#' 13
 #'
 #' B2 (Mean brightness): Mean relative reflectance over the entire spectral range.
-#' This is prefered to B1 since values are easier to compare across studies. REF 5, 11
+#' This is prefered to B1 since values are easier to compare across studies. REF 4, 12
 #'
 #' B3 (Intensity): Maximum relative reflectance (Reflectance at wavelength of maximum
-#' reflectance). Note that may be sensitive to noise near the peak. REF 1, 7, 9
+#' reflectance). Note that may be sensitive to noise near the peak. REF 1, 5, 6
 #' 
 #' S1 (Chroma): Relative contribution of a spectral range to the total brightness (B1)
 #' S1 is arbitrarily devided in 6 measures of chroma based on the wavelength ranges 
 #' normally associated with specific hues. The values are calculated using the 
 #' following ranges: S1U (UV, if applicable): lambda min-400nm; 
 #' S1v (Violet) lambda min-415nm; S1B (Blue) 400nm-510nm; S1G (Green) 510nm-605nm;
-#' S1Y (Yellow) 550nm-625nm; S1R (Red) 605nm-lambda max. REF 3, 4, 6, 11-13
+#' S1Y (Yellow) 550nm-625nm; S1R (Red) 605nm-lambda max. REF 2, 7, 8, 11-13
 #'
 #' S2 (Spectral saturation): Rmax/Rmin This measure is sensitive to spectral noise.
 #' Proper interpretation of this value may be difficult for spectra with multiple
@@ -50,7 +49,7 @@
 #' within 50nm of either the minimum or maximum range of the data will not be comparable 
 #' since the area under the curve for the area of interest will not always 
 #' be based on the same wavelength range. Therefore, S3 should be interpreted 
-#' with caution for peaks in the UV or Red range. REF 13
+#' with caution for peaks in the UV or Red range. REF 11
 #'
 #' S4 (Spectral purity): |bmaxneg| , calculated by approximating the derivative
 #' of the spectral curve. As such, it is very sensitive to noise and should only
@@ -59,52 +58,58 @@
 #' curves for brown and red surfaces, for example, should not generate a values. REF 1
 #'
 #' S5 (Chroma): Similar in design to segment classification measures (see Montgomerie 2006)
-#' for details. REF 8
+#' for details. REF 10
 #'
 #' S6 (Contrast): Rmax - Rmin. Because it uses both Rmin and Rmax, this measure may be
-#' sensitive to spectral noise. REF 7, 9
+#' sensitive to spectral noise. REF 5, 6
 #' 
 #' S7 (Spectral saturation): Relative reflectance between the area around the peak with
 #' reflectance equal to or larger to half of that of the peak (an approximation to the
 #' full-width at half maxima. See Montgomerie (2006) for details). Somewhat sensitive 
 #' to noise and can be misleading when more than one maxima and/or minima are present.
-#' REF 2, 10
+#' REF 3, 9
 #'
 #' S8 (Chroma): (Rmax - Rmin)/B2. Because it uses both Rmin and Rmax, this measure may be
-#' sensitive to spectral noise. REF 2, 6
+#' sensitive to spectral noise. REF 3, 13
 #'
 #' S9 (Carotenoid chroma): (R450 - R700)/R700. Should only be used when the color 
 #' of the surface is clearly due to carotenoid pigmentation and R450 is lower than
-#' R700. Could be sensitive to noise. REF 12
+#' R700. Could be sensitive to noise. REF 8
 #' 
 #' S10 (Peaky chroma): (Rmax - Rmin)/B2 x |bmaxneg|. Should be used with properly 
-#' smoothed curves. REF 3
+#' smoothed curves. REF 7
 #'
 #' H1 (Peak wavelength, hue): Wavelength of maximum reflectance. May be sensitive to noise
-#' and may be variable if there is more than one maxima. REF 1, 3-7, 11, 13
+#' and may be variable if there is more than one maxima. REF 1, 2, 4, 6, 7, 10-13
 #'
-#' H2 (Hue): Wavelength at bmaxneg. Should be calculated using smoothed data. REF 4, 6
+#' H2 (Hue): Wavelength at bmaxneg. Should be calculated using smoothed data. REF 2, 13
 #'
 #' H3 (Hue): Wavelength at Rmid. Sensitive to noisy spectra and may be variable if there are
-#' more than one maxima and minima. REF 2, 6, 10
+#' more than one maxima and minima. REF 3, 9, 13
 #'
 #' H4 (Hue): Similar in design to segment classification measures see Montgomerie
-#' (2006) for details. REF 8
+#' (2006) for details. REF 10
 #' 
 #' H5 (Hue): Wavelength at bmax. Sensitive to noise and may be variable if there is
-#' more than one maxima and minima. REF 9
+#' more than one maxima and minima. REF 5
 #' @note If minimum wavelength is over 400, UV chroma is not computed.
 #' @note Variables which compute bmax and bmaxneg should be used with caution, for they
 #' rely on smoothed curves to remove noise, which would otherwise result in spurious
 #' results. Make sure chosen smoothing parameters are adequate.
 #' @note Smoothing affects only B3, S2, S4, S6, S10, H2, and H5 calculation. All other 
 #' variables can be reliably extracted using non-smoothed data. 
+#' 
+#' @export
+#' 
 #' @examples \dontrun{
 #' data(sicalis)
 #' summary(sicalis)
 #' summary(sicalis, subset = TRUE)
-#' summary(sicalis, subset = c('B1', 'H4')) }
+#' summary(sicalis, subset = c('B1', 'H4'))
+#' }
+#' 
 #' @author Pierre-Paul Bitton \email{bittonp@@windsor.ca}, Rafael Maia \email{rm72@@zips.uakron.edu}
+#' 
 #' @references Montgomerie R. 2006. Analyzing colors. In Hill, G.E, and McGraw, K.J., eds. 
 #' Bird Coloration. Volume 1 Mechanisms and measuremements. Harvard University Press, Cambridge, Massachusetts.
 #' @references References describing variables:
@@ -153,7 +158,7 @@
 #'
 #' 13- Smiseth, P., J. Ornborg, S. Andersson, and T. Amundsen. 2001. Is male plumage reflectance
 #' correlated with paternal care in bluethroats? Behavioural Ecology 12:164-170.
-
+#'
 summary.rspec <- function (object, subset = FALSE, wlmin = NULL, wlmax = NULL, ...) {
 
 wl_index <- which(names(object)=='wl')
@@ -181,11 +186,16 @@ if(is.null(wlmin)){
 
      lambdamax <- wlmax
      }
-    
+
 # restrict to range of wlmin:wlmax
 object <- object[which(wl==lambdamin):which(wl==lambdamax),]
 wl <- object[,wl_index]
-object <- object[,-wl_index]
+
+# CE begin edit:
+select <- (1:ncol(object))[-wl_index]
+# object <- object[,-wl_index]
+object <- object[select]
+# CE end edit
 
 output.mat <- matrix (nrow=(dim(object)[2]), ncol=23)
 
@@ -266,16 +276,16 @@ Q2 <- which(wl==segmts[2]):which(wl==segmts[3])
 Q3 <- which(wl==segmts[3]):which(wl==segmts[4])
 Q4 <- which(wl==segmts[4]):which(wl==segmts[5])
 
-S5R <- apply(object[Q4, ],2,sum)/B1
-S5Y <- apply(object[Q3, ],2,sum)/B1
-S5G <- apply(object[Q2, ],2,sum)/B1
-S5B <- apply(object[Q1, ],2,sum)/B1
+S5R <- apply(as.data.frame(object[Q4, ]), 2, sum) 
+S5Y <- apply(as.data.frame(object[Q3, ]), 2, sum) 
+S5G <- apply(as.data.frame(object[Q2, ]), 2, sum) 
+S5B <- apply(as.data.frame(object[Q1, ]), 2, sum) 
 
 S5 <- sqrt((S5R-S5G)^2+(S5Y-S5B)^2)
 
-#H4 <- atan(((S5Y-S5B)/B1)/((S5R-S5G)/B1))
-# H4 <- atan2((S5R-S5G)/B1, (S5Y-S5B)/B1)
-H4 <- atan2(S5R-S5G, S5Y-S5B)
+H4 <- atan(((S5Y-S5B)/B1)/((S5R-S5G)/B1))
+#H4 <- atan2((S5R-S5G)/B1, (S5Y-S5B)/B1)
+#H4 <- atan2(S5R-S5G, S5Y-S5B)
 
 # Carotenoid chroma
 
@@ -327,6 +337,7 @@ H3 <- sapply(1:ncol(H3object), function(x) {
 })
 H3 <- H3wl[H3]
 
+
 # H2
 diffsmooth <- apply(object,2,diff)
 
@@ -338,7 +349,7 @@ bmaxneg <- abs(apply(diffsmooth,2,min)) #S4
   bmaxneg[which(apply(diffsmooth,2,min) > 0)] <- NA
 
 # S10
-S10 <- S8/bmaxneg #S10
+S10 <- S8*bmaxneg #S10
  S10[which(apply(diffsmooth,2,min) > 0)] <- NA
 
 # H5
@@ -362,7 +373,7 @@ lambdabmax <- wl[apply(diffsmooth,2,which.max)] #H5
   output.mat[, 18] <- S10 
   output.mat[, 19] <- H1
   output.mat[, 20] <- lambdabmaxneg 
-  output.mat[, 21] <- H3 #Rmid
+  output.mat[, 21] <- H3 # Rmid
   output.mat[, 22] <- H4
   output.mat[, 23] <- lambdabmax
 
